﻿using System;
using UnityEngine;
using Windows.Kinect;

public class CoordinateMapperView : MonoBehaviour
{
	private ComputeBuffer DepthBuffer,
                          BodyIndexBuffer;

	private DepthSpacePoint[] DepthPoints;
	private byte[] BodyIndexPoints;

    void Start ()
	{
        var CoordinateMapperManager = GameObject.Find("Managers").GetComponent<CoordinateMapperManager>();
        CoordinateMapperManager.enabled = true;

        var material = GetComponent<Renderer>().material;

        material.SetTexture("_MainTex", CoordinateMapperManager.ColorTexture);
        
        DepthBuffer     = GenerateBuffer("depthCoordinates", sizeof(float) * 2,
                                         (DepthPoints = CoordinateMapperManager.DepthCoordinates), material);
        BodyIndexBuffer = GenerateBuffer("BodyIndexBuffer", sizeof(float),
                                         (BodyIndexPoints = CoordinateMapperManager.BodyIndexBuffer), material);
    }

    ComputeBuffer GenerateBuffer(string name, int stride, Array points, Material material)
    {
        var buffer = new ComputeBuffer(points.Length, stride);
        material.SetBuffer(name, buffer);
        return buffer;
    }

	void Update()
	{
		//TODO: fix perf on this call.
		DepthBuffer.SetData(DepthPoints);
        
		BodyIndexBuffer.SetData(Array.ConvertAll(BodyIndexPoints, Convert.ToSingle));
	}
	
	void OnDisable() 
	{
        DepthBuffer.Release();   
        BodyIndexBuffer.Release();
    }
}
